@@ -5,7 +5,7 @@ use Moose;
 with 'Pod::Weaver::Role::AddTextToSection';
 with 'Pod::Weaver::Role::Section';
 
-has show_source => (is=>'rw');
+has show_source => (is=>'rw', default=>sub {1});
 has include_schema_module => (is=>'rw');
 has exclude_schema_module => (is=>'rw');
 has include_schemas_module => (is=>'rw');
@@ -19,7 +19,7 @@ sub mvp_multivalue_args { qw(
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2024-01-08'; # DATE
 our $DIST = 'Pod-Weaver-Plugin-Sah-Schemas'; # DIST
-our $VERSION = '0.077'; # VERSION
+our $VERSION = '0.078'; # VERSION
 
 sub weave_section {
     no strict 'refs'; ## no critic: TestingAndDebugging::ProhibitNoStrict
@@ -446,7 +446,7 @@ Pod::Weaver::Plugin::Sah::Schemas - Plugin to use when building Sah::Schemas::*
 
 =head1 VERSION
 
-This document describes version 0.077 of Pod::Weaver::Plugin::Sah::Schemas (from Perl distribution Pod-Weaver-Plugin-Sah-Schemas), released on 2024-01-08.
+This document describes version 0.078 of Pod::Weaver::Plugin::Sah::Schemas (from Perl distribution Pod-Weaver-Plugin-Sah-Schemas), released on 2024-01-08.
 
 =head1 SYNOPSIS
 
@@ -483,7 +483,7 @@ It does the following to L<lib/Sah/Schema/*> .pm files:
 
 =head2 show_source
 
-Bool. Default false. If set to true, will add a C<SAH SCHEMA DEFINITION> section
+Bool. Default true. If set to true, will add a C<SAH SCHEMA DEFINITION> section
 containing the source (dump) of the schema. Examples will be stripped.
 
 =head2 include_schema_module
